# lexx

[![PyPI - Version](https://img.shields.io/pypi/v/lexx.svg)](https://pypi.org/project/lexx)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/lexx.svg)](https://pypi.org/project/lexx)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install lexx
```

## License

`lexx` is distributed under the terms of the [MIT][] license. The word
generation code is taken from [lexifer][] by William S. Annis, also released
under the MIT license.

[MIT]: https://spdx.org/licenses/MIT.html
[lexifer]: https://lingweenie.org/conlang/lexifer.html
